@@ -17,7 +17,7 @@ class MinioBackend(BackendBase):
     
     def geturl(self, entrypoint):
         bucket, bucket_name = entrypoint.split('/')
-        return 'http://{}/{}_{}'.format(self.domain, bucket, bucket_name)
+        return 'http://{}/{}/{}_{}'.format(self.domain, self.default_bucket, bucket, bucket_name)
 
     def put(self, file, bucket, bucket_name, tmp=True):
         try:
