@@ -43,8 +43,7 @@ class Qiniu(BackendBase):
             print('upload failed.')
             return False, '上传失败'
         except Exception as e:
-            traceback.print_exc()
-            return False, str(e)
+            return False, traceback.format_exc()
     
     async def put_async(self, file, bucket, bucket_name, tmp=True):
         return self.put(file, bucket, bucket_name, tmp)
