@@ -208,8 +208,11 @@ async def extra_tasks():
             if affected_records > 0:
                 print('data cleaned')
 
-            if is_time_in_range('04:00', '04:05'):
+            if is_time_in_range('04:00', '06:00'):
+                if cache_engine.get_cache('hmfs_cleanup'):
+                    continue
                 await hmfs_client.cleanup_cloud()
+                cache_engine.cache('hmfs_cleanup', 1, expired=7200)
         except:
             traceback.print_exc()
         finally:
@@ -218,10 +221,10 @@ async def extra_tasks():
 def run():
     file_transfer_get.consume()
     file_transfer_put.consume()
-    # # file_transfer_del.consume()
+    # file_transfer_del.consume()
 
     # asyncio.get_event_loop().run_until_complete(file_transfer_put('qiniu://tmp_file_test/test.jpg', 'test', 'test.jpg', -1))
     
     loop = asyncio.new_event_loop()
     loop.run_until_complete(extra_tasks())
-    
\ No newline at end of file
+    # asyncio.get_event_loop().run_until_complete(hmfs_client.cleanup_cloud())
\ No newline at end of file
