@@ -6,6 +6,7 @@ class Singleton(object):
         key = str(cls) + str(args) + str(kwargs)
         if key not in cls._instance_:
             cls._instance_[key] = super().__new__(cls)
+            cls._instance_[key].__key__ = key
         return cls._instance_[key]
     
     def need_init(self):
@@ -13,4 +14,8 @@ class Singleton(object):
 
     def __init__(self, *args, **kwargs):
         pass
+
+    def dispose(self):
+        print('collect memory instance: {}'.format(self.__key__))
+        del self._instance_[self.__key__]
     
\ No newline at end of file
